<?php

namespace NoccyLabs\React\Http2\Header;

use ArrayIterator;
use IteratorAggregate;
use NoccyLabs\React\Http2\Huffman\Codec;
use NoccyLabs\React\Http2\Huffman\Dictionary;
use Traversable;

/**
 * An ordered list of HTTP/2 headers
 * 
 * 
 */
class HeaderBag implements IteratorAggregate
{

    private array $headers = [];

    public function __construct(array $headers = [])
    {
        foreach ($headers as $name=>$value) $this->append($name, $value);
    }

    public function append(string $name, string $value)
    {
        $this->headers[] = [$name, $value ];
    }

    public function getAllHeaders(): array
    {
        return $this->headers;
    }

    public function getHeaders(string $name): ?array
    {
        return array_map(fn($v) => $v[1], array_filter($this->headers, fn($v) => $v[0] == $name));
    }

    public function getHeaderLine(string $name): ?string
    {
        $headers = $this->getHeaders($name);
        return array_shift($headers);
    }

    public function getIterator(): Traversable
    {
        return new ArrayIterator($this->headers);
    }
}